@@ -156,7 +156,7 @@ gpg_error_t lock_file_mutex(struct client_s *client)
 #endif
     }
     else
-	MUTEX_TRYLOCK(client->ctx, m, rc);
+	MUTEX_TRYLOCK(client, m, rc);
 
     if (!rc)
 	client->has_lock = TRUE;
@@ -186,7 +186,8 @@ void cleanup_client(struct client_s *client)
 {
     assuan_context_t ctx = client->ctx;
     struct client_thread_s *thd = client->thd;
-    gboolean has_lock = client->has_lock;
+    gboolean lock_on_open = client->lockonopen;
+    gboolean rc_on_locked = client->rc_on_locked;
 #ifdef WITH_PINENTRY
     struct pinentry_s *pin = client->pinentry;
 #endif
@@ -212,7 +213,8 @@ void cleanup_client(struct client_s *client)
 #ifdef WITH_PINENTRY
     client->pinentry = pin;
 #endif
-    client->has_lock = has_lock;
+    client->rc_on_locked = rc_on_locked;
+    client->lockonopen = lock_on_open;
 }
 
 static void gz_cleanup(void *arg)
