@@ -470,9 +470,9 @@ void close_file_header(file_header_internal_t *fh)
     g_free(fh);
 }
 
-void cleanup_crypto(struct client_crypto_s **c)
+void cleanup_crypto(struct crypto_s **c)
 {
-    struct client_crypto_s *cr = *c;
+    struct crypto_s *cr = *c;
 
     if (!cr)
 	return;
@@ -779,7 +779,7 @@ static gchar *do_read_password(const gchar *prompt)
 
 /* Only used when "enable_pinentry" is "false" or -P. */
 static gpg_error_t read_password(const gchar *filename,
-	struct client_crypto_s *crypto, guchar *key, pinentry_cmd_t which)
+	struct crypto_s *crypto, guchar *key, pinentry_cmd_t which)
 {
     gchar *prompt;
 
@@ -829,7 +829,7 @@ static gpg_error_t read_password(const gchar *filename,
 /*
  * inbuf must have been allocated with gcry_malloc().
  */
-gpg_error_t export_common(const gchar *filename, struct client_crypto_s *crypto,
+gpg_error_t export_common(const gchar *filename, struct crypto_s *crypto,
 	gpointer inbuf, gulong insize)
 {
     gpg_error_t rc;
@@ -859,7 +859,7 @@ gpg_error_t export_common(const gchar *filename, struct client_crypto_s *crypto,
 }
 
 static gpg_error_t get_password(const gchar *filename,
-	struct client_crypto_s *crypto, guchar *md5file, guchar *key,
+	struct crypto_s *crypto, guchar *md5file, guchar *key,
 	pinentry_cmd_t which)
 {
 #ifdef WITH_PINENTRY
@@ -906,7 +906,7 @@ static gboolean xml_import(const gchar *filename, const gchar *outfile,
     xmlChar *xmlbuf;
     xmlChar *xml;
     gpg_error_t rc;
-    struct client_crypto_s *crypto;
+    struct crypto_s *crypto;
     guint hashlen = gcry_md_get_algo_dlen(GCRY_MD_SHA256);
 
     if (stat(filename, &st) == -1) {
@@ -931,13 +931,13 @@ static gboolean xml_import(const gchar *filename, const gchar *outfile,
 	    filename, outfile);
 
     if (iter && keyfile) {
-	crypto->tkey = parse_rcfile_keyfile(keyfile, TRUE, &rc);
+	rc = parse_rcfile_keyfile(crypto, keyfile, TRUE);
 
-	if (!crypto->tkey)
+	if (rc)
 	    goto fail;
 
 	gcry_md_hash_buffer(GCRY_MD_SHA256, crypto->key, crypto->tkey,
-		strlen(crypto->tkey) ? strlen(crypto->tkey) : 1);
+		crypto->tkey_len);
     }
     else if (iter) {
 	rc = get_password(outfile, crypto, NULL, crypto->key, PINENTRY_SAVE);
@@ -1024,12 +1024,13 @@ fail:
     return FALSE;
 }
 
-gboolean do_cache_push(const gchar *filename, const gchar *password)
+gboolean do_cache_push(const gchar *filename, const void *password,
+	gsize len)
 {
     guchar md5file[16];
     gint timeout;
     const gchar *p = filename;
-    struct client_crypto_s *crypto;
+    struct crypto_s *crypto;
     gpg_error_t rc;
     guint hashlen = gcry_md_get_algo_dlen(GCRY_MD_SHA256);
 
@@ -1046,6 +1047,11 @@ gboolean do_cache_push(const gchar *filename, const gchar *password)
 
     gcry_md_hash_buffer(GCRY_MD_MD5, md5file, p, strlen(p));
 
+    if (cache_iscached(md5file)) {
+	log_write(N_("%s: already cached, skipping"), p);
+	return FALSE;
+    }
+
     if (access(p, R_OK|W_OK) != 0) {
 	log_write("%s: %s", p, strerror(errno));
 	return FALSE;
@@ -1092,8 +1098,7 @@ gboolean do_cache_push(const gchar *filename, const gchar *password)
 	crypto->fh->doc = NULL;
     }
     else
-	gcry_md_hash_buffer(GCRY_MD_SHA256, crypto->key, password,
-		strlen(password) ? strlen(password) : 1);
+	gcry_md_hash_buffer(GCRY_MD_SHA256, crypto->key, password, len);
 
 try_decrypt:
     rc = init_client_crypto2(filename, crypto);
@@ -1576,7 +1581,7 @@ guint pwmd_cipher_str_to_cipher(const gchar *str)
 /* To be called after read_file_header(). This sets the wanted algorithm from
  * .flags */
 gpg_error_t init_client_crypto2(const char *filename,
-	struct client_crypto_s *crypto)
+	struct crypto_s *crypto)
 {
     gpg_error_t rc;
     guint algo;
@@ -1619,9 +1624,9 @@ gpg_error_t init_client_crypto2(const char *filename,
     return gcry_cipher_open(&crypto->gh, algo, GCRY_CIPHER_MODE_CBC, 0);
 }
 
-struct client_crypto_s *init_client_crypto()
+struct crypto_s *init_client_crypto()
 {
-    struct client_crypto_s *new = g_malloc0(sizeof(struct client_crypto_s));
+    struct crypto_s *new = g_malloc0(sizeof(struct crypto_s));
 
     if (!new) {
 	log_write("%s(%i): %s", __FILE__, __LINE__, strerror(ENOMEM));
@@ -1637,7 +1642,7 @@ static gpg_error_t convert_file(const gchar *filename, const gchar *keyfile,
     gpg_error_t rc;
     guchar md5file[gcry_md_get_algo_dlen(GCRY_MD_MD5)];
     guint64 iter;
-    struct client_crypto_s *crypto = init_client_crypto();
+    struct crypto_s *crypto = init_client_crypto();
     guint hashlen = gcry_md_get_algo_dlen(GCRY_MD_SHA256);
 
     if (!crypto)
@@ -1665,13 +1670,15 @@ static gpg_error_t convert_file(const gchar *filename, const gchar *keyfile,
      */
     if (crypto->fh->ver.fh1.iter != -1) {
 	if (keyfile) {
-	     crypto->tkey = parse_rcfile_keyfile(keyfile, TRUE, &rc);
+	     rc = parse_rcfile_keyfile(crypto, keyfile, TRUE);
 
-	    if (!crypto->tkey)
+	    if (rc)
 		goto done;
 
 	    gcry_md_hash_buffer(GCRY_MD_SHA256, crypto->key, crypto->tkey,
-		    strlen(crypto->tkey) ? strlen(crypto->tkey) : 1);
+		    crypto->tkey_len);
+	    gcry_free(crypto->tkey);
+	    crypto->tkey = NULL;
 	}
 	else {
 	    rc = get_password(filename, crypto, md5file, crypto->key,
@@ -2019,7 +2026,7 @@ int main(int argc, char *argv[])
      */
     if (cache_push) {
 	for (opt = 0; cache_push[opt]; opt++)
-	    do_cache_push(cache_push[opt], NULL);
+	    do_cache_push(cache_push[opt], NULL, 0);
 
 	g_strfreev(cache_push);
 	log_write(background ? N_("Done. Daemonizing...") : N_("Done. Waiting for connections..."));
