@@ -86,7 +86,7 @@ gpg_error_t new_root_element(xmlDocPtr doc, gchar *name)
 	p++;
 
     if (!valid_xml_element((xmlChar *)p))
-	return EPWMD_INVALID_ELEMENT;
+	return GPG_ERR_INV_VALUE;
 
     n = xmlNewNode(NULL, (xmlChar *)"element");
     n = xmlAddChild(root, n);
@@ -168,7 +168,7 @@ gpg_error_t list_root_elements(xmlDocPtr doc, GString **result)
     n = xmlDocGetRootElement(doc);
 
     if (!n || !n->children)
-	return EPWMD_EMPTY_ELEMENT;
+	return GPG_ERR_NO_VALUE;
 
     for (n = n->children; n; n = n->next) {
 	xmlAttrPtr a;
@@ -239,7 +239,7 @@ gpg_error_t list_root_elements(xmlDocPtr doc, GString **result)
     total = g_slist_length(list);
 
     if (!total)
-	return EPWMD_EMPTY_ELEMENT;
+	return GPG_ERR_NO_VALUE;
 
     string = g_string_new(NULL);
 
@@ -301,7 +301,7 @@ xmlNodePtr create_target_elements_cb(xmlNodePtr node, gchar **path,
 	    is_literal_element(&req[i]);
 
 	    if (!valid_xml_element((xmlChar *)req[i])) {
-		*rc = EPWMD_INVALID_ELEMENT;
+		*rc = GPG_ERR_INV_VALUE;
 		return NULL;
 	    }
 
@@ -398,7 +398,7 @@ xmlNodePtr create_elements_cb(xmlNodePtr node, gchar **elements,
 
 	if (!n) {
 	    if (!valid_xml_element((xmlChar *)req[i])) {
-		*rc = EPWMD_INVALID_ELEMENT;
+		*rc = GPG_ERR_INV_VALUE;
 		return NULL;
 	    }
 
@@ -450,10 +450,10 @@ xmlNodePtr find_root_element(xmlDocPtr doc, gchar ***req, gpg_error_t *rc,
     if (max_recursion_depth >= 1 && recursion_depth > max_recursion_depth) {
 	xmlChar *t = xmlGetNodePath(n);
 
-	log_write("%s: %s", pwmd_strerror(EPWMD_LOOP), t);
+	log_write("%s: %s", pwmd_strerror(GPG_ERR_ELOOP), t);
 	xmlFree(t);
 	g_free(root);
-	*rc = EPWMD_LOOP;
+	*rc = GPG_ERR_ELOOP;
 	return NULL;
     }
 
@@ -557,7 +557,7 @@ xmlNodePtr find_root_element(xmlDocPtr doc, gchar ***req, gpg_error_t *rc,
     }
 
     g_free(root);
-    *rc = EPWMD_ELEMENT_NOT_FOUND;
+    *rc = GPG_ERR_ELEMENT_NOT_FOUND;
     return NULL;
 }
 
@@ -631,10 +631,10 @@ xmlNodePtr find_elements(xmlDocPtr doc, xmlNodePtr node,
     if (max_recursion_depth >= 1 && recursion_depth > max_recursion_depth) {
 	xmlChar *t = xmlGetNodePath(node);
 
-	log_write("%s: %s", pwmd_strerror(EPWMD_LOOP), t);
+	log_write("%s: %s", pwmd_strerror(GPG_ERR_ELOOP), t);
 	xmlFree(t);
 	recursion_depth--;
-	*rc = EPWMD_LOOP;
+	*rc = GPG_ERR_ELOOP;
 	return NULL;
     }
 
@@ -656,7 +656,7 @@ xmlNodePtr find_elements(xmlDocPtr doc, xmlNodePtr node,
 	    if (not_found_fn)
 		return not_found_fn(found ? last_node : last_node->parent, p, rc, data);
 
-	    *rc = EPWMD_ELEMENT_NOT_FOUND;
+	    *rc = GPG_ERR_ELEMENT_NOT_FOUND;
 	    return NULL;
 	}
 
@@ -690,14 +690,14 @@ xmlNodePtr find_elements(xmlDocPtr doc, xmlNodePtr node,
 	    if (strchr((gchar *)content, '\t') != NULL) {
 		if ((nreq = split_input_line((gchar *)content, "\t", 0)) == NULL) {
 		    xmlFree(content);
-		    *rc = EPWMD_INVALID_ELEMENT;
+		    *rc = GPG_ERR_INV_VALUE;
 		    return NULL;
 		}
 	    }
 	    else {
 		if ((nreq = split_input_line((gchar *)content, " ", 0)) == NULL) {
 		    xmlFree(content);
-		    *rc = EPWMD_INVALID_ELEMENT;
+		    *rc = GPG_ERR_INV_VALUE;
 		    return NULL;
 		}
 	    }
@@ -820,11 +820,11 @@ static gpg_error_t path_list_recurse(xmlDocPtr doc, xmlNodePtr node,
 
 	    if (max_recursion_depth >= 1 && elements->depth > max_recursion_depth) {
 		xmlChar *t = xmlGetNodePath(n);
-		log_write("%s: %s", pwmd_strerror(EPWMD_LOOP), t);
+		log_write("%s: %s", pwmd_strerror(GPG_ERR_ELOOP), t);
 		xmlFree(t);
 		xmlFree(target);
 		xmlFree(a);
-		return EPWMD_LOOP;
+		return GPG_ERR_ELOOP;
 	    }
 
 	    if (strv_printf(&elements->elements, "%s\t%s", elements->prefix, a) == FALSE) {
@@ -934,7 +934,7 @@ gpg_error_t create_path_list(xmlDocPtr doc, struct element_list_s *elements,
 	req = split_input_line(path, " ", 0);
 
 	if (!req)
-	    return EPWMD_COMMAND_SYNTAX;
+	    return GPG_ERR_SYNTAX;
     }
 
     req_orig = g_strdupv(req);
@@ -946,7 +946,7 @@ gpg_error_t create_path_list(xmlDocPtr doc, struct element_list_s *elements,
 
     n = find_root_element(doc, &req, &rc, &a_target, 0, FALSE);
 
-    if (!n && rc == EPWMD_ELEMENT_NOT_FOUND && elements->resolving == TRUE) {
+    if (!n && rc == GPG_ERR_ELEMENT_NOT_FOUND && elements->resolving == TRUE) {
 	rc = 0;
 	goto fail;
     }
@@ -963,7 +963,7 @@ gpg_error_t create_path_list(xmlDocPtr doc, struct element_list_s *elements,
 
 	n = find_elements(doc, n->children, req+1, &rc, &e_target, NULL, NULL, TRUE, 0, NULL, FALSE);
 
-	if (!n && rc == EPWMD_ELEMENT_NOT_FOUND && elements->resolving == TRUE) {
+	if (!n && rc == GPG_ERR_ELEMENT_NOT_FOUND && elements->resolving == TRUE) {
 	    rc = 0;
 	    goto fail;
 	}
@@ -1139,7 +1139,7 @@ gpg_error_t delete_attribute(xmlNodePtr n, const xmlChar *name)
     xmlAttrPtr a;
 
     if ((a = xmlHasProp(n, name)) == NULL)
-	return EPWMD_ATTR_NOT_FOUND;
+	return GPG_ERR_NOT_FOUND;
 
     if (xmlRemoveProp(a) == -1)
 	return EPWMD_LIBXML_ERROR;
@@ -1244,7 +1244,7 @@ gpg_error_t validate_import(xmlNodePtr node)
 
 		    log_write(N_("Missing attribute '_name' at %s."), t);
 		    xmlFree(t);
-		    return EPWMD_INVALID_ELEMENT;
+		    return GPG_ERR_INV_VALUE;
 		}
 
 		if (!valid_xml_element(a)) {
@@ -1253,7 +1253,7 @@ gpg_error_t validate_import(xmlNodePtr node)
 		    log_write(N_("'%s' is not a valid element name at %s."), a, t);
 		    xmlFree(a);
 		    xmlFree(t);
-		    return EPWMD_INVALID_ELEMENT;
+		    return GPG_ERR_INV_VALUE;
 		}
 
 		xmlFree(a);
